#include "FTPmeView.h"
#include <Application.h>

FTPmeView::FTPmeView(): BView(mainViewFrame, "mainView", B_FOLLOW_LEFT|B_FOLLOW_TOP, B_WILL_DRAW)
{
	const rgb_color BKG_GREY		= { 216, 216, 216, 0 };
	SetViewColor(BKG_GREY);
	
	username = new BTextControl(usernameFrame, B_EMPTY_STRING, "Username:", "", NULL);
	username->SetDivider(55);
	password = new PassControl(passwordFrame, B_EMPTY_STRING, "Password:", "", NULL);
	password->SetDivider(55);
	site = new BTextControl(siteFrame, B_EMPTY_STRING, "Site:", "", NULL);
	site->SetDivider(30);
	path = new BTextControl(pathFrame, B_EMPTY_STRING, "Path:", "", NULL);
	path->SetDivider(30);
	
	anonymous = new BCheckBox(anonymousFrame, B_EMPTY_STRING, "Anonymous", new BMessage(ANON_EVENT));
	log = new BCheckBox(logFrame, B_EMPTY_STRING, "Keep Log", new BMessage('poip'));
	
	go = new BButton(goButtonFrame, "go", "Go", new BMessage(GO_EVENT));
	
	strcpy(tempuser,"");
	strcpy(temppass,"");
	AddChild(username);
	AddChild(password);
	AddChild(site);
	AddChild(path);
	AddChild(anonymous);
	AddChild(log);
	AddChild(go);
	
	LoadSettings();
}

const char *FTPmeView::Username() const
{
	return username->Text();
}

const char *FTPmeView::ActualPassword() const
{
	return password->actualText();
}

const char *FTPmeView::Site() const
{
	return site->Text();
}

const char *FTPmeView::Path() const
{
	return path->Text();
}

int32 FTPmeView::LogValue() const
{
	return log->Value();
}

void FTPmeView::AnonymousToggle()
{
	if (anonymous->Value() == B_CONTROL_OFF) {
		username->SetText(tempuser);
		password->SetText("*****");
		password->SetActual(temppass);
	}
	else {
		sprintf(tempuser, "%s", username->Text());
		sprintf(temppass, "%s", password->actualText());
		username->SetText("anonymous");
		password->SetText("email@email.com");
		password->SetActual("email@email.com");
	}
}

void FTPmeView::LoadSettings()
{
	BPath settings_path;
	find_directory(B_USER_SETTINGS_DIRECTORY, &settings_path);
	settings_path.SetTo(settings_path.Path(), "FTPme_settings");
	BFile *settings = new BFile();
	status_t result;
	result = settings->SetTo(settings_path.Path(), B_READ_ONLY);
	if (result == B_NO_ERROR)
	{
		const char *tempstring[100];
		int32 tempint32=0;
		BMessage *settings_msg = new BMessage(SETTINGS);
		settings_msg->Unflatten(settings);
		settings_msg->FindString("USER", tempstring);
		username->SetText(*tempstring);
		settings_msg->FindString("PASS", tempstring);
		password->SetText("*****");
		password->SetActual(*tempstring);
		settings_msg->FindString("SITE", tempstring);
		site->SetText(*tempstring);
		settings_msg->FindString("PATH", tempstring);
		path->SetText(*tempstring);
		settings_msg->FindInt32("ANON", tempint32);
		//anonymous->SetValue(tempint32);
	}
	settings->Unset();
}

void FTPmeView::SaveSettings()
{
	BPath settings_path;
	find_directory(B_USER_SETTINGS_DIRECTORY, &settings_path);
	settings_path.SetTo(settings_path.Path(), "FTPme_settings");
	BFile *settings = new BFile(settings_path.Path(), B_READ_WRITE| B_CREATE_FILE| B_ERASE_FILE);
	BMessage *settings_msg = new BMessage(SETTINGS);
	settings_msg->AddString("USER", username->Text());
	settings_msg->AddString("PASS", password->actualText());
	settings_msg->AddString("SITE", site->Text());
	settings_msg->AddString("PATH", path->Text());
	settings_msg->AddInt32("ANON", anonymous->Value());
	settings_msg->Flatten(settings);
}

void FTPmeView::MessageReceived(BMessage *message)
{
	switch(message->what)
	{
		case GO_EVENT:
			break;
		case ANON_EVENT:
			AnonymousToggle();
			break;
		default: ;
	}
}